#
# ADA334901-fishing.R, 17 Sep 23
#
# Data from:
# An investigation into the use of software product metrics for COBOL systems
# 1st Lt Richard E. Boone
#
# pdf2txt is broken on the archive.org version
# Use https://apps.dtic.mil/sti/citations/ADA334901
# Analysed for a post on https://shape-of-code.com

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


num_prog_paras=function(df)
{
t=count(df$Program)
return (t[order(t$freq, decreasing=TRUE),  ])
}



cob=read.csv("ADA334901.csv", as.is=TRUE, fill=TRUE)

noexit=subset(cob, !grepl("EXIT", Paragraph))

points(count(cob$stmts))
plot(count(cob$stmts), log="xy",
	xlab="Statements", ylab="Paragraphs")

points(1, count(noexit$stmts)$freq[2], col=pal_col[1])

dev.copy(dev=png, file="Cobol-para-stmts.png")
dev.off()

prog_paras=num_prog_paras(cob)

plot(prog_paras$freq,, log="y", col=pal_col[1],
	xaxs="i",
	xlim=c(0, nrow(prog_paras)),
	xlab="Program rank", ylab="Paragraphs")

noexit_pp=num_prog_paras(noexit)
points(noexit_pp$freq, col=pal_col[2])

legend("bottomleft", legend=c("All paragraphs", "excluding EXIT paragraphs"),
                        fill=pal_col, border="white", bty="n")

dev.copy(dev=png, file="Cobol-prog-paras.png")
dev.off()

# Some basic summary stats
length(unique(cob$Program))
length(unique(cob$Paragraph))
sum(cob$stmts, na.rm=TRUE)
length(unique(noexit$Paragraph))
(length(unique(cob$Paragraph))- length(unique(noexit$Paragraph)))/ length(unique(cob$Paragraph))

